PatternLockLinkageSettings class

Constructors

PatternLockLinkageSettings({int maxLinkDistance = 1, bool allowRepetitions = false})
const

Properties

allowRepetitions bool
Whether the already activated pattern cell can be activated again from the last activated cell. Cycles (repeated connections from activated cell to another activated cell) are never allowed.
final
hashCode int
The hash code for this object.
no setterinherited
maxLinkDistance int
Controls how far the current pattern cell can be from the last selected cell for current cell to be activated.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited