allowRepetitions property

bool allowRepetitions
final

Whether the already activated pattern cell can be activated again from the last activated cell. Cycles (repeated connections from activated cell to another activated cell) are never allowed.

Implementation

final bool allowRepetitions;