firstDate property
This is the earliest date a user can select.
If null, this will default to DateTime.now().
Implementation
final DateTime? firstDate;
This is the earliest date a user can select.
If null, this will default to DateTime.now().
final DateTime? firstDate;