PatternLockCellActivationArea class
Specify this to customize what counts as
close enough to center of cell for this cell to be activated.
Constructors
- PatternLockCellActivationArea({required double dimension, required PatternLockCellAreaUnits units, required PatternLockCellAreaShape shape})
-
const
Properties
- dimension → double
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- shape → PatternLockCellAreaShape
-
final
- units → PatternLockCellAreaUnits
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited