maxLinkDistance property
Controls how far the current pattern cell can be from the last selected cell for current cell to be activated.
Think of this in terms of how a knight moves in chess.
This integer controls the length of the longer side of knight's movement
that is considered okay.
Let dx be x-axis difference in cell coordinates; Let dy be y-axis difference in cell coordinates;
Then allowed cell coordinates are given by: math.max(dy, dx) <= maxLinkDistance.
maxLinkDistance = 1 allows movement in only 8 directions to adjacent cells,
maxLinkDistance = 2 allows movement to all adjacent cells and like a knight in chess, and so on
Horizontal, vertical, or diagonal skips are never allowed.
Implementation
final int maxLinkDistance;