SwitchAppearance class
Constructors
- SwitchAppearance({Size trackSize = _appSwitchDefaultTrackSize, Widget thumbBuilder(BuildContext ctx, double anim)?, Widget trackBuilder(BuildContext ctx, double anim)?})
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- thumbBuilder → Widget Function(BuildContext ctx, double anim)?
-
final
- trackBuilder → Widget Function(BuildContext ctx, double anim)?
-
final
- trackSize → Size
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited